<?php

class SipWizard 
{
	// scenario variables
	var $pbx 	    = 'Pbx';
	var $which_scenario = 1;

	// sip variables
	var $sip_name 	  = array('id' => 'sip-name' 	, 'name' => 'sip_name'	  , 'title' => SIP_NAME_DIS			, 'tooltip' => TRUNKS_SIP_NAME	   , 'type' => 'text'	 );
	var $sip_server   = array('id' => 'sip-server'  , 'name' => 'sip_server'  , 'title' => WIZARD_SIP_SERVER_ADDRESS_DIS	, 'tooltip' => TRUNKS_SIP_REGISTRAR, 'type' => 'text'	 );
	var $sip_user 	  = array('id' => 'sip-user'	, 'name' => 'sip_user'	  , 'title' => SIP_USER_DIS			, 'tooltip' => TRUNKS_SIP_USER	   , 'type' => 'text'	 );
	var $sip_secret	  = array('id' => 'sip-secret'  , 'name' => 'sip_secret'  , 'title' => SIP_SECRET_DIS			, 'tooltip' => TRUNKS_SIP_SECRET   , 'type' => 'password');
	var $sip_register = array('id' => 'sip-register', 'name' => 'sip_register', 'title' => SIP_REGISTER_DIS			, 'tooltip' => TRUNKS_SIP_REGISTER , 'type' => 'checkbox');

	// pbx variables 
	var $pbx_server = array('id' => 'pbx-server', 'name' => 'pbx_server', 'title' => WIZARD_PBX_SERVER_ADDR_DIS, 'tooltip' => '', 'type' => 'text');
	var $pbx_port	= array('id' => 'pbx-port'  , 'name' => 'pbx_port'  , 'title' => WIZARD_PBX_SERVER_PORT_DIS, 'tooltip' => '', 'type' => 'text');

	function __construct ($scenario = 1) // gateway = 1    -   pbx = 2   -   provider = 3    -    manual = 4
	{
		$this -> which_scenario = $scenario;
	}

	// private
	function _display_simple_field ($parameter, $value = '', $javascript = '')
	{
		$checked = '';
		$class 	 = "class='form-control input-sm'";
		if (strcmp($parameter['type'], 'checkbox') == 0)
		{
			$class   = "class=''";
			$checked = ((strlen($value) != 0 || $value) ? ' checked' : '');
		}

		$html_str = 	  "\t\t\t<div class='form-group' id='{$parameter['id']}-tr'>\n"
				. "\t\t\t\t<label for='{$parameter['name']}' class='col-sm-3 control-label'>{$parameter['title']}</label>\n"
				. "\t\t\t\t<div class='col-sm-8'>\n"
				. "\t\t\t\t\t<input type='{$parameter['type']}' $class data-toggle='tooltip' name='{$parameter['name']}' id='{$parameter['id']}' title='{$parameter['tooltip']}' value='$value' $javascript $checked/>\n"
				. "\t\t\t\t</div>\n"
				. "\t\t\t</div>\n";
	
		return $html_str;
	}

	function _manual_content($sip_cfg)
	{
		$html_str = '';
		
		foreach (array($this -> sip_name, $this -> sip_server, $this -> sip_user, $this -> sip_secret, $this -> sip_register) as $sip_parameter)
		{
			$value = (isset($sip_cfg[$sip_parameter['name']]) ? $sip_cfg[$sip_parameter['name']] : '');
			$html_str .= $this -> _display_simple_field($sip_parameter, $value);
		}

		return $html_str;
	}

	function _gateway_content($ba, $sip_cfg)
	{
		return $this -> _manual_content($sip_cfg);
	}

	function _pbx_content($pbx_cfg)
	{
		$html_str = '';

		foreach (array($this -> pbx_server, $this -> pbx_port) as $pbx_parameter)
		{ 
			$value = (isset($pbx_cfg[$pbx_parameter['name']]) ? $pbx_cfg[$pbx_parameter['name']] : ''); 
			$html_str .= $this -> _display_simple_field($pbx_parameter, $value);
		}
		
		return $html_str;
	}

	// public
	function get_content_modal ($ba, $wizard_cfg, &$title_modal) 
	{
		switch ($this -> which_scenario)
		{
			default:
			case 1:
				return $this -> _gateway_content($ba, $wizard_cfg);
			case 2:
				$title_modal = WIZARD_PBX_SETTINGS_DIS;
				return $this -> _pbx_content($wizard_cfg);
		}
	}

	function get_javascript_code ($form)
	{
		if ($this -> which_scenario == 1)
		{
			ob_start();
?>
<script type="text/javascript">
        $(document).ready(function () {
                $("#<?php echo $form; ?>").validate({
                        rules: {
                                <?php echo $this -> sip_name['name']; ?>: {
                                        required: true,
                                },
                                <?php echo $this -> sip_server['name']; ?>: {
                                        required: true,
                                },
                        }
                });
        });
</script>
<?php
			return ob_get_clean();
		}
		else if ($this -> which_scenario == 2)
		{
			ob_start();
?>
<script type="text/javascript">
        $(document).ready(function () {
                $("#<?php echo $form; ?>").validate({
                        rules: {
                                <?php echo $this -> pbx_server['name']; ?>: {
                                        required: true,
                                },
                                <?php echo $this -> pbx_port['name']; ?>: {
                                        digits: true,
                                },
                        }
                });
        });
</script>
<?php
			return ob_get_clean();
		}

		return '';
	}

	function organize_settings ($sip_cfg)
	{
		$string_erased = "sip_";
		if ($this -> which_scenario == 2)
		{
			$string_erased = "pbx_";
		}

		$organized_settings = array();
		foreach ($sip_cfg as $parameter => $value)
		{
			if (preg_match("#$string_erased#", $parameter))
			{
				$organized_settings[str_replace($string_erased, '', $parameter)] = $value;
			}
		}

		return $organized_settings;
	}

	function get_summary_settings ($scenario, $settings)
	{
		// title
		$title = "\t\t\t<p class='text-center h5'>". ($scenario == 2 ? WIZARD_PBX_SETTINGS_DIS : WIZARD_SIP_SETTING_DIS) ."</p>\n";

		// table
		$th_titles = '';
		$td_values = '';
		foreach ($settings as $parameter => $value)
		{
			if (strcmp($parameter, 'secret') != 0)
			{
				$th_titles .= "<th>". ucfirst($parameter) ."</th>";
				$td_values .= "<td>$value</td>"	   		  ;
			}
		}

		$table =  "\t\t\t<table class='table table-striped table-bordered'>\n"
			. "\t\t\t\t<tr>". $th_titles ."</tr>\n"
			. "\t\t\t\t<tr>". $td_values ."</tr>\n"
			. "\t\t\t</table>\n";

		return $title . $table; 
	}
}
?>
